#!/usr/bin/env python3

import numpy as np
import collections.abc
import PyQt5  # noqa: F401

import artiq.applets.simple


class NumberWidget(PyQt5.QtWidgets.QLCDNumber):
    """Extended and backwards compatible version of the standard ARTIQ big number applet."""

    def __init__(self, args):
        # Call super
        super(NumberWidget, self).__init__()
        # Set number of digits
        self.setDigitCount(args.digit_count)
        # Store dataset name
        self.dataset_name = args.dataset

    def data_changed(self, data, _):
        try:
            # Get data
            n = data[self.dataset_name][1]
            if isinstance(n, (collections.abc.Sequence, np.ndarray)):
                # Pick the last element if we are dealing with a sequence
                n = n[-1]
            # Convert to float
            n = float(n)
        except (KeyError, ValueError, TypeError, IndexError):
            # Could not obtain data
            n = "---"

        # Display value
        self.display(n)


def main():
    # Create applet object
    applet = artiq.applets.simple.SimpleApplet(NumberWidget)

    # Add custom arguments
    applet.argparser.add_argument("--digit-count", type=int, default=10,
                                  help="Total number of digits to show")

    # Add datasets
    applet.add_dataset("dataset", "Dataset to show")
    applet.run()


if __name__ == "__main__":
    main()
